@@ -11,6 +11,8 @@
 #include "ConvertToGrid.h"
 #include <SDL.h>
 
+using namespace beego;
+
 
 int main(int argc, char *argv[]) {
 
@@ -28,7 +30,7 @@ int main(int argc, char *argv[]) {
     fprintf(stderr, "n = %d\n", n);
   } else {
     std::vector<Grid<int> > points;
-    convertToGrid(points, data, data_max, urg);
+    convertToGrid(points, data, data_max, &urg);
     for (std::vector<Grid<int> >::iterator it = points.begin();
 	 it != points.end(); ++it) {
       printf("%d\t%d\n", it->x, it->y);
