@@ -5,6 +5,9 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  usage:
+  ./(this program) --urg_port=(COM Port)
 */
 
 #include "UrgCtrl.h"
@@ -16,14 +19,9 @@ using namespace beego;
 
 int main(int argc, char *argv[]) {
 
-  const char*const device = "/dev/usb/ttyUSB0";
-  //const char*const device = "/dev/ttyACM0";
-  //const char*const device = "COM4";
-  const long baudrate = 115200;
-
   size_t first_ticks = GetTicks();
   UrgCtrl urg;
-  if (! urg.connect(device, baudrate)) {
+  if (! urg.connect(argc, argv)) {
     printf("UrgCtrl::connect: %s\n", urg.what());
     exit(1);
   }
