@@ -5,6 +5,9 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  usage:
+  ./(this program) --urg_port=(COM Port)
 */
 
 #include "UrgCtrl.h"
@@ -16,16 +19,9 @@ using namespace beego;
 
 int main(int argc, char *argv[]) {
 
-  // œnꂽfoCXp
-  const char* device = "/dev/ttyACM0";
-  //const char* device = "/dev/usb/ttyUSB0";
-  if (argc > 1) {
-    device = argv[1];
-  }
-
   // ZTƂ̐ڑ
   UrgCtrl urg;
-  if (! urg.connect(device)) {
+  if (! urg.connect(argc, argv)) {
     printf("UrgCtrl::connect: %s\n", urg.what());
     exit(1);
   }
