@@ -5,6 +5,9 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  usage:
+  ./(this program) --urg_port=(COM Port)
 */
 
 #include "UrgCtrl.h"
@@ -15,10 +18,8 @@ using namespace beego;
 
 int main(int argc, char *argv[]) {
 
-  const char device[] = "/dev/ttyACM0";
-
   UrgCtrl urg;
-  if (! urg.connect(device)) {
+  if (! urg.connect(argc, argv)) {
     printf("UrgCtrl::connect: %s\n", urg.what());
     exit(1);
   }
