@@ -29,12 +29,6 @@ void beego::convertToGrid(std::vector<Grid<int> >& points, long data[],
     p.x = static_cast<int>(length * cos(radian)) + offset.x;
     p.y = static_cast<int>(length * sin(radian)) + offset.y;
 
-#if 0
-    if (i == size/2) {
-      fprintf(stderr, "(%d, %d), ", p.x, p.y);
-    }
-#endif
-
     points.push_back(p);
   }
 }
