@@ -9,6 +9,7 @@
 
 #include "Delay.h"
 #include "SdlInit.h"
+#include "LockGuard.h"
 #include "DetectOS.h"
 #ifdef MSC
 #include "SDL_win.h"
@@ -16,6 +17,8 @@
 #include <SDL.h>
 #endif
 
+using namespace beego;
+
 
 static double WaitRatio = 1.0;
 static SDL_mutex* Mutex = NULL;
@@ -42,13 +45,13 @@ static void mutexInitialize(void) {
 
   \param msec [i] ҋ@ [msec]
 */
-void delay(unsigned long msec) {
+void beego::delay(unsigned long msec) {
   mutexInitialize();
 
-  SDL_LockMutex(Mutex);
+  LockMutex(Mutex);
   unsigned long delay_msec =
     static_cast<unsigned long>(msec * WaitRatio);
-  SDL_UnlockMutex(Mutex);
+  UnlockMutex(Mutex);
 
   SDL_Delay(delay_msec);
 }
@@ -64,7 +67,7 @@ void delay(unsigned long msec) {
 void setDelayRatio(double ratio) {
   mutexInitialize();
 
-  SDL_LockMutex(Mutex);
+  LockMutex(Mutex);
   WaitRatio = ratio;
-  SDL_UnlockMutex(Mutex);
+  UnlockMutex(Mutex);
 }
