@@ -24,6 +24,6 @@
 #endif
 
 
-bool existFile(const char* file_path) {
+bool beego::existFile(const char* file_path) {
   return (access(file_path, F_OK) == 0) ? true : false;
 }
