@@ -8,9 +8,6 @@
   access() ̃bp[
 
   \author Satofumi KAMIMURA
-
-  \todo SearchFilePath Å֐Ă΂悤ɂ
-  \todo SearchFilePath Ńt@CL𒲂ׂĂӏu
 */
 
 namespace beego {
