@@ -12,13 +12,15 @@
   \todo monitor Ήɂ
 */
 
-/*!
-  \brief vO쎞Ԃ̎擾
+namespace beego {
+  /*!
+    \brief vO쎞Ԃ̎擾
 
-  \return vO쎞 [msec]
+    \return vO쎞 [msec]
 
-  \attention ۂɂ́ASDL_Init() Ă΂Ă̎ԂƂȂB
-*/
-extern size_t GetTicks(void);
+    \attention ۂɂ́ASDL_Init() Ă΂Ă̎ԂƂȂB
+  */
+  extern size_t GetTicks(void);
+};
 
 #endif /* !GET_TICKS_H */
