@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief
+  \brief SDL  Windows lCeBu
 
   \author Satofumi KAMIMURA
 
