@@ -15,7 +15,6 @@
 #include "MathUtils.h"
 #include "GetTicks.h"
 #include "Delay.h"
-
 //#include "ConnectionLogger.h"
 
 using namespace beego;
@@ -29,9 +28,6 @@ struct ScipHandler::pImpl {
     TotalTimeout = 1000,
     Timeout = 800,
 
-    // !!! win32 ł rapid ̏̂߁A500 ɂĂ邪A130 ɖ߂
-    //Timeout = 130,
-
     //LineLength = 64 + 1 + 1 + 1,
     // !!! Aȉ폜āA̎ɖ߂ׂ
     LineLength = 16 + 64 + 1 + 1 + 1, // 64 ȏ̃f[^ɑΏ
@@ -148,7 +144,6 @@ struct ScipHandler::pImpl {
 #endif
     if (n < recv_size) {
       // !!! error_message
-      //fprintf(stderr, "%d, %d: [return %d]\n", n, recv_size, RecvIncomplete);
       error_message = "XX 1";
       return RecvIncomplete;
     }
@@ -275,12 +270,9 @@ bool ScipHandler::isConnected(void) const {
 bool ScipHandler::adjustBaudrate(long baudrate) {
 
   // "SCIP2.0" p{[[g킹
-  //long try_baudrate[] = { 115200, 19200, 57600, };
   long try_baudrate[] = { 19200, 115200, 57600, };
   for (size_t i = 0; i < sizeof(try_baudrate)/sizeof(try_baudrate[0]); ++i) {
-    //fprintf(stderr, "\nchange baudrate\n");
     bool ret = pimpl->con->changeBaudrate(try_baudrate[i]);
-    //pimpl->con->flush();
     if (ret == false) {
       pimpl->error_message = pimpl->con->what();
       return false;
@@ -293,8 +285,6 @@ bool ScipHandler::adjustBaudrate(long baudrate) {
     int recv_n = 0;
     if (reply != 0x00) {
       reply = pimpl->sendMessage("SCIP2.0", pImpl::Timeout, &recv_n);
-      //fprintf(stderr, "SCIP2.0: reply: %02x\n", reply);
-      //fprintf(stderr, "recv_n: %d\n", recv_n);
       //  0x00 or 0x0e ł΁Aɓ{[[gƂ݂Ȃ
       if ((recv_n < 0) && (reply < 0)) {
 	// ^CAEǵA{[[gႤƍl̂ōăeXg
@@ -302,26 +292,18 @@ bool ScipHandler::adjustBaudrate(long baudrate) {
       }
     }
 
-    // recv_n == 11 ̍Lqׂ
-    if ((reply == 0x00) || (reply == 0x0e) || (recv_n == 11)) {
+    enum { SCIP1_REPLY_SIZE = 11, };
+    if ((reply == 0x00) || (reply == 0x0e) || (recv_n == SCIP1_REPLY_SIZE)) {
       size_t before_ticks = GetTicks();
       ret = setBaudrate(baudrate);
       int reply_msec = GetTicks() - before_ticks;
-      //fprintf(stderr, "reply_msec: %d, %d\n", reply_msec, reply_msec *4/3);
-      //fprintf(stderr, "setBaudrate return: %s\n", (ret) ? "true" : "false");
       if (ret) {
 	// zXg̃{[[gύX
-	//pimpl->con->flush();
-	//fprintf(stderr, "reply: %02x\n", reply);
 	pimpl->con->changeBaudrate(baudrate);
-	if ((reply == 0x00) || (recv_n == 11)) {
+	if ((reply == 0x00) || (recv_n == SCIP1_REPLY_SIZE)) {
 	  // VAʐM̏ꍇA{[[gύXAP҂Kv
-	  // !!! O܂ł̉Ԃ҂悤ɂ΁AʂȂ
 	  delay(reply_msec *4/3 + 10);
-	  //delay(100);
-	  //fprintf(stderr, "ticks (after delay): %d\n", GetTicks());
 	}
-	//pimpl->con->flush();
 	return true;
       }
     }
@@ -338,7 +320,6 @@ bool ScipHandler::setBaudrate(long baudrate) {
   char buffer[] = "SS000000";
   sprintf(buffer, "SS%06ld", baudrate);
   int reply = pimpl->sendMessage(buffer, pImpl::Timeout);
-  //fprintf(stderr, "setBaudrate reply: %d\n", reply);
 
   // Top-URG ւ̎bΉƂāA0xE ł true ԂĂ
   // Top-URG p SCIP2.0  SS T|[g΁A0xE ͍̏폜
@@ -433,11 +414,6 @@ bool ScipHandler::loadSensorParameter(SensorParameter* parameter) {
       pimpl->params.scan_rpm = atoi(&buffer[5]);
     }
   }
-#if 0
-  fprintf(stderr, "last line_index: %d, %d\n", line_index,
-	  Other + SensorParameter::SCAN);
-  fprintf(stderr, "ticks: %d\n", GetTicks());
-#endif
 
   if (line_index <= Other + SensorParameter::SCAN) {
     return false;
@@ -466,13 +442,7 @@ void ScipHandler::setCaptureTimes(size_t times) {
 
 void ScipHandler::sendCaptureMessage(char cmd) {
 
-  // !!! ̊֐ŁAQT ̑MKvłΑΏs
-
-  // Timeout Ԃ́Ascan_rpm ̂P + 30 [msec] Ƃ
-  // !!! pImpl ̃oƂĐ錾āAȂƂ銴ȁH
-
   pimpl->remain_byte = 0;
-
   char send_message[pImpl::LineLength];
   if (cmd == 'M') {
     sprintf(send_message, "M%c%04d%04d%02d%01d%02d",
@@ -487,8 +457,8 @@ void ScipHandler::sendCaptureMessage(char cmd) {
 	    pimpl->first, pimpl->last,
 	    pimpl->groups);
   }
+
   // !!! ߂l̃`FbNׂBꉞ
-  //int send_size = pimpl->sendTag(send_message);
   pimpl->sendTag(send_message);
 }
 
@@ -509,15 +479,13 @@ int ScipHandler::recvCaptureData(long* data, size_t max_size,
   size_t local_timestamp = 0;
   for (int i = 0; (line_length = pimpl->readLine(buffer)) >= 0; ++i) {
 
-    //fprintf(stderr, "%02d: %s\n", i, buffer);
-
     // `FbNT̊mF
     // !!!
     // !!! return false;
 
     if ((i >= 6) && (line_length == 0)) {
+
       // f[^M̊
-#if 1
       for (size_t i = pimpl->recv_data.size(); i < max_size; ++i) {
 	// f[^܂ł 19(vL͈͊O)Ŗ߂
 	pimpl->recv_data.push_back(19);
@@ -527,16 +495,6 @@ int ScipHandler::recvCaptureData(long* data, size_t max_size,
       }
       timestamp = local_timestamp;
       return pimpl->recv_data.size();
-#else
-      int data_size = pimpl->recv_data.size();
-      size_t min_length =
-	(static_cast<int>(max_size) < data_size) ? max_size : data_size;
-      for (size_t i = 0; i < min_length; ++i) {
-	data[i] = pimpl->recv_data[i];
-      }
-      timestamp = local_timestamp;
-      return min_length;
-#endif
 
     } else if (i == 0) {
       // MbZ[W̍ŏ݂̂̕ŃbZ[W̔s
@@ -554,7 +512,7 @@ int ScipHandler::recvCaptureData(long* data, size_t max_size,
       i = 4;
 
       // !!! 'G' R}h̎c񐔂́AŎo
-      // !!! ׂ
+      // !!! oāALLɂׂ
       if (0) {
 	pimpl->laser_on = false;
 	pimpl->possible_remain = false;
@@ -564,6 +522,7 @@ int ScipHandler::recvCaptureData(long* data, size_t max_size,
       // MpPbgɑ΂鉞
       // !!!
       // MIA[U[͒~
+      // !!! IoāALLɂׂ
       if (0) {
 	pimpl->laser_on = false;
       }
@@ -719,21 +678,16 @@ int ScipHandler::rad2index(const double radian) {
 
 size_t ScipHandler::getImmediateTimestamp(int* estimated_delay) {
 
-  // !!! Г̒ʐMxԂA肵 estimated_delay Ɋi[ĕԂ
-  // !!!
+  // Г̒ʐMxԂA肵 estimated_delay Ɋi[ĕԂ
 
   bool laser_state = pimpl->laser_on;
-
   int reply = pimpl->sendMessage("TM0", pImpl::Timeout);
   pimpl->laser_on = false;
 
-  //size_t first_ticks = GetTicks();
   long last_timestamp = 0;
-  //reply = pimpl->sendMessage("TM1", pImpl::Timeout);
   pimpl->sendTag("TM1");
 
-  // !!! ȉAЂǂB̂Aƍ蒼
-  //if (reply == 0) {
+  // !!! ȉA蒼
   if (1) {
     char buffer[pImpl::LineLength];
 
