@@ -10,9 +10,11 @@
 #include "SearchFilePath.h"
 #include "ExistFile.h"
 
+using namespace beego;
 
-bool searchFilePath(std::string& full_path, const char* fname,
-		    const std::vector<std::string>& dir_path) {
+
+bool beego::searchFilePath(std::string& full_path, const char* fname,
+			   const std::vector<std::string>& dir_path) {
 
   // t@C݂̑ɊmF
   std::vector<std::string> search_dir = dir_path;
