@@ -14,18 +14,19 @@
 #include <vector>
 
 
-/*!
-  \brief pX̃t@C̒T
+namespace beego {
+  /*!
+    \brief pX̃t@C̒T
 
-  \param full_path [o] Tʂ̃tpX
-  \param fname [i] t@C
-  \param dir_path [i] pX̔z
+    \param full_path [o] Tʂ̃tpX
+    \param fname [i] t@C
+    \param dir_path [i] pX̔z
 
-  \retval true t@CTɐAfull_path ɒTʂ̃tpXi[
-  \retval false t@CTɎs
+    \retval true t@CTɐAfull_path ɒTʂ̃tpXi[
+    \retval false t@CTɎs
 
-  gp
-  \code
+    gp
+    \code
 // ./beegoconf ܂ ~/.beego/beegoconf ̒T
 std::vector<std::string> search_path;
 search_path.push_back("./");
@@ -35,9 +36,10 @@ std::string config_file;
 if (searchFilePath(config_file, "beegoconf", search_path)) {
    ...
 }
-  \endcode
-*/
-extern bool searchFilePath(std::string& full_path, const char* fname,
-			   const std::vector<std::string>& dir_path);
+    \endcode
+  */
+  extern bool searchFilePath(std::string& full_path, const char* fname,
+			     const std::vector<std::string>& dir_path);
+};
 
 #endif /* SEARCH_FILE_PATH_H */
