@@ -20,14 +20,14 @@ namespace beego {
   class SensorParameter {
   public:
     enum {
-      MODL = 0,
-      DMIN,
-      DMAX,
-      ARES,
-      AMIN,
-      AMAX,
-      AFRT,
-      SCAN,
+      MODL = 0,			//!< ZT^
+      DMIN,			//!< ŏv\ [mm]
+      DMAX,			//!< őv\ [mm]
+      ARES,			//!< px\(360x̕)
+      AMIN,			//!< ŏv\l
+      AMAX,			//!< őv\l
+      AFRT,			//!< ʕl
+      SCAN,			//!< Wpx
     };
     std::string model;
     long distance_min;
