@@ -6,8 +6,6 @@
   \author Tomoaki YOSHIDA
 
   $Id$
-
-  \todo update() ܂̌؂
 */
 
 #include "SerialCtrl.h"
@@ -148,7 +146,7 @@ bool SerialCtrl::connect(const char* device, long baudrate) {
     char buffer[256];
 
     //DWORD error = GetLastError();
-    // !!! lpMsg ̎ǵAۗB荞
+    // !!! lpMsg ̎gmFA荞
     //sprintf(buffer, "port(%s) open failed: %s\n", device); //, lpMsg);
     sprintf(buffer, "port(%s) open failed\n", device); //, lpMsg);
     pimpl->error_message = buffer;
